==> tikiwiki-1.9.11.tgz: tikiwiki/img/flags/flagnames.php <==
<?php // -*- coding:utf-8 -*- $Header: /cvsroot/tikiwiki/tiki/img/flags/flagnames.php,v 1.1.2.9 2007/03/02 13:57:35 luciash Exp $
/* 
 * The listing associates country names used as filenames for flags in Tikiwiki for language translation
 */

// This script is only for language translations - so its better to die if called directly.
if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
  header("location: index.php");
	exit;
}

// Here come the dynamically generated strings for img/flags/*.gif
tra('Andorra');
tra('United_Arab_Emirates');
tra('Afghanistan');
tra('Antigua');
tra('Anguilla');
tra('Albania');
tra('Armenia');
tra('Netherlands_Antilles');
tra('Angola');
tra('Antarctica');
tra('Argentina');
tra('American_Samoa');
tra('Austria');
tra('Australia');
tra('Aruba');
tra('Aland_Islands');
tra('Azerbaijan');
tra('Bosnia_and_Herzegovina');
tra('Barbados');
tra('Bangladesh');
tra('Belgium');
tra('Burkina_Faso');
tra('Bulgaria');
tra('Bahrain');
tra('Burundi');
tra('Benin');
tra('Bermuda');
tra('Brunei');
tra('Bolivia');
tra('Brazil');
tra('Bahamas');
tra('Bhutan');
tra('Bouvet_Island');
tra('Botswana');
tra('Belarus');
tra('Belize');
tra('Canada');
tra('Catalan_Countries');
tra('Cocos_Islands');
tra('Central_African_Republic');
tra('Congo_Democratic');
tra('Congo');
tra('Switzerland');
tra('Ivory_Coast');
tra('Cook_Islands');
tra('Chile');
tra('Cameroon');
tra('China');
tra('Colombia');
tra('Costa_Rica');
tra('Cuba');
tra('Cape_Verde');
tra('Christmas_Island');
tra('Cyprus');
tra('Czech_Republic');
tra('Germany');
tra('Djibouti');
tra('Denmark');
tra('Dominica');
tra('Dominican_Republic');
tra('Algeria');
tra('Ecuador');
tra('Estonia');
tra('Egypt');
tra('Western_Sahara');
tra('Eritrea');
tra('Spain');
tra('Ethiopia');
tra('Finland');
tra('Fiji');
tra('Falkland_Islands');
tra('Federated_States_of_Micronesia');
tra('Faroe_Islands');
tra('France');
tra('Gabon');
tra('United_Kingdom');
tra('Grenada');
tra('Georgia');
tra('French_Guiana');
tra('Guernsey');
tra('Ghana');
tra('Gibraltar');
tra('Greenland');
tra('Gambia');
tra('Guinea');
tra('Guadeloupe');
tra('Equatorial_Guinea');
tra('Greece');
tra('South_Georgia_and_South_Sandwich_Islands');
tra('Guatemala');
tra('Guam');
tra('Guinea_Bissau');
tra('Guyana');
tra('Hong_Kong');
tra('Heard_Island_and_McDonald_Islands');
tra('Honduras');
tra('Croatia');
tra('Haiti');
tra('Hungary');
tra('Indonesia');
tra('Ireland');
tra('Israel');
tra('Isle_of_Man');
tra('India');
tra('British_Indian_Ocean_Territory');
tra('Iraq');
tra('Iran');
tra('Iceland');
tra('Italy');
tra('Jersey');
tra('Jamaica');
tra('Jordan');
tra('Japan');
tra('Kenya');
tra('Kyrgyzstan');
tra('Cambodia');
tra('Kiribati');
tra('Comoros');
tra('Saint_Kitts_and_Nevis');
tra('North_Korea');
tra('South_Korea');
tra('Kuwait');
tra('Cayman_Islands');
tra('Kazakstan');
tra('Laos');
tra('Lebanon');
tra('Saint_Lucia');
tra('Liechtenstein');
tra('Sri_Lanka');
tra('Liberia');
tra('Lesotho');
tra('Lithuania');
tra('Luxemburg');
tra('Latvia');
tra('Libya');
tra('Morocco');
tra('Monaco');
tra('Moldova');
tra('Montenegro');
tra('Madagascar');
tra('Marshall_Islands');
tra('Macedonia');
tra('Mali');
tra('Myanmar');
tra('Mongolia');
tra('Macao');
tra('Northern_Mariana_Islands');
tra('Martinique');
tra('Mauritania');
tra('Montserrat');
tra('Malta');
tra('Mauritius');
tra('Maldives');
tra('Malawi');
tra('Mexico');
tra('Malaysia');
tra('Mozambique');
tra('Namibia');
tra('New_Caledonia');
tra('Niger');
tra('Norfolk_Island');
tra('Nigeria');
tra('Nicaragua');
tra('Netherlands');
tra('Norway');
tra('Nepal');
tra('Nauru');
tra('Niue');
tra('New_Zealand');
tra('Oman');
tra('Panama');
tra('Peru');
tra('French_Polynesia');
tra('Papua_New_Guinea');
tra('Phillippines');
tra('Pakistan');
tra('Poland');
tra('Saint_Pierre_and_Miquelon');
tra('Pitcairn');
tra('Puerto_Rico');
tra('Palestine');
tra('Portugal');
tra('Palau');
tra('Paraguay');
tra('Quatar');
tra('Reunion');
tra('Romania');
tra('Serbia');
tra('Russia');
tra('Rwanda');
tra('Saudi_Arabia');
tra('Solomon_Islands');
tra('Seychelles');
tra('Sudan');
tra('Sweden');
tra('Singapore');
tra('Saint_Helena');
tra('Slovenia');
tra('Svalbard_and_Jan_Mayen');
tra('Slovakia');
tra('Sierra_Leone');
tra('San_Marino');
tra('Senegal');
tra('Somalia');
tra('Surinam');
tra('Sao_Tome_and_Principe');
tra('El_Salvador');
tra('Syria');
tra('Swaziland');
tra('Turks_and_Caicos_Islands');
tra('Chad');
tra('French_Southern_Territories');
tra('Togo');
tra('Thailand');
tra('Tajikistan');
tra('Tokelau');
tra('Timor-Leste');
tra('Turkmenistan');
tra('Tunisia');
tra('Tonga');
tra('Turkey');
tra('Trinidad_Tobago');
tra('Tuvalu');
tra('Taiwan');
tra('Tanzania');
tra('Ukraine');
tra('Uganda');
tra('United_States_Minor_Outlying_Islands');
tra('United_States');
tra('Uruguay');
tra('Uzbekistan');
tra('Vatican');
tra('St_Vincent_Grenadines');
tra('Venezuela');
tra('British_Virgin_Islands');
tra('US_Virgin_Islands');
tra('Viet_Nam');
tra('Vanuatu');
tra('Wales');
tra('Wallis_and_Futuna');
tra('World');
tra('Samoa');
tra('Yemen');
tra('Mayotte');
tra('South_Africa');
tra('Zambia');
tra('Zimbabwe');
tra('Europe');
tra('Yugoslavia');
?>

==> tikiwiki-2.2.tgz: tikiwiki/img/flags/flagnames.php <==
<?php // -*- coding:utf-8 -*- $Id: /cvsroot/tikiwiki/tiki/img/flags/flagnames.php,v 1.10 2007-03-02 19:49:20 luciash Exp $
/* 
 * The listing associates country names used as filenames for flags in Tikiwiki for language translation
 */

// This script is only for language translations - so its better to die if called directly.
if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
  header("location: index.php");
	exit;
}

// Here come the dynamically generated strings for img/flags/*.gif
tra('Afghanistan');
tra('Aland Islands');
tra('Albania');
tra('Algeria');
tra('American Samoa');
tra('Andorra');
tra('Angola');
tra('Anguilla');
tra('Antarctica');
tra('Antigua');
tra('Argentina');
tra('Armenia');
tra('Aruba');
tra('Australia');
tra('Austria');
tra('Azerbaijan');
tra('Bahamas');
tra('Bahrain');
tra('Bangladesh');
tra('Barbados');
tra('Belarus');
tra('Belgium');
tra('Belize');
tra('Benin');
tra('Bermuda');
tra('Bhutan');
tra('Bolivia');
tra('Bosnia and Herzegovina');
tra('Botswana');
tra('Bouvet Island');
tra('Brazil');
tra('British Indian Ocean Territory');
tra('British Virgin Islands');
tra('Brunei');
tra('Bulgaria');
tra('Burkina Faso');
tra('Burundi');
tra('Cambodia');
tra('Cameroon');
tra('Canada');
tra('Cape Verde');
tra('Catalan Countries');
tra('Cayman Islands');
tra('Central African Republic');
tra('Chad');
tra('Chile');
tra('China');
tra('Christmas Island');
tra('Cocos Islands');
tra('Colombia');
tra('Comoros');
tra('Congo');
tra('Congo Democratic');
tra('Cook Islands');
tra('Costa Rica');
tra('Croatia');
tra('Cuba');
tra('Cyprus');
tra('Czech Republic');
tra('Denmark');
tra('Djibouti');
tra('Dominica');
tra('Dominican Republic');
tra('Ecuador');
tra('Egypt');
tra('El Salvador');
tra('Equatorial Guinea');
tra('Eritrea');
tra('Estonia');
tra('Ethiopia');
tra('Europe');
tra('Falkland Islands');
tra('Faroe Islands');
tra('Federated States of Micronesia');
tra('Fiji');
tra('Finland');
tra('France');
tra('French Guiana');
tra('French Polynesia');
tra('French Southern Territories');
tra('Gabon');
tra('Gambia');
tra('Georgia');
tra('Germany');
tra('Ghana');
tra('Gibraltar');
tra('Greece');
tra('Greenland');
tra('Grenada');
tra('Guadeloupe');
tra('Guam');
tra('Guatemala');
tra('Guernsey');
tra('Guinea');
tra('Guinea Bissau');
tra('Guyana');
tra('Haiti');
tra('Heard Island and McDonald Islands');
tra('Honduras');
tra('Hong Kong');
tra('Hungary');
tra('Iceland');
tra('India');
tra('Indonesia');
tra('Iran');
tra('Iraq');
tra('Ireland');
tra('Isle of Man');
tra('Israel');
tra('Italy');
tra('Ivory Coast');
tra('Jamaica');
tra('Japan');
tra('Jersey');
tra('Jordan');
tra('Kazakstan');
tra('Kenya');
tra('Kiribati');
tra('Kuwait');
tra('Kyrgyzstan');
tra('Laos');
tra('Latvia');
tra('Lebanon');
tra('Lesotho');
tra('Liberia');
tra('Libya');
tra('Liechtenstein');
tra('Lithuania');
tra('Luxemburg');
tra('Macao');
tra('Macedonia');
tra('Madagascar');
tra('Malawi');
tra('Malaysia');
tra('Maldives');
tra('Mali');
tra('Malta');
tra('Marshall Islands');
tra('Martinique');
tra('Mauritania');
tra('Mauritius');
tra('Mayotte');
tra('Mexico');
tra('Moldova');
tra('Monaco');
tra('Mongolia');
tra('Montenegro');
tra('Montserrat');
tra('Morocco');
tra('Mozambique');
tra('Myanmar');
tra('Namibia');
tra('Nauru');
tra('Nepal');
tra('Netherlands');
tra('Netherlands Antilles');
tra('New Caledonia');
tra('New Zealand');
tra('Nicaragua');
tra('Niger');
tra('Nigeria');
tra('Niue');
tra('None');
tra('Norfolk Island');
tra('Northern Mariana Islands');
tra('North Korea');
tra('Norway');
tra('Oman');
tra('Other');
tra('Pakistan');
tra('Palau');
tra('Palestine');
tra('Panama');
tra('Papua New Guinea');
tra('Paraguay');
tra('Peru');
tra('Philippines');
tra('Pitcairn');
tra('Poland');
tra('Portugal');
tra('Puerto Rico');
tra('Quatar');
tra('Republic of Macedonia');
tra('Reunion');
tra('Romania');
tra('Russia');
tra('Rwanda');
tra('Saint Helena');
tra('Saint Kitts and Nevis');
tra('Saint Lucia');
tra('Saint Pierre and Miquelon');
tra('Samoa');
tra('San Marino');
tra('Sao Tome and Principe');
tra('Saudi Arabia');
tra('Senegal');
tra('Serbia');
tra('Seychelles');
tra('Sierra Leone');
tra('Singapore');
tra('Slovakia');
tra('Slovenia');
tra('Solomon Islands');
tra('Somalia');
tra('South Africa');
tra('South Georgia and South Sandwich Islands');
tra('South Korea');
tra('Spain');
tra('Sri Lanka');
tra('St Vincent Grenadines');
tra('Sudan');
tra('Surinam');
tra('Svalbard and Jan Mayen');
tra('Swaziland');
tra('Sweden');
tra('Switzerland');
tra('Syria');
tra('Taiwan');
tra('Tajikistan');
tra('Tanzania');
tra('Thailand');
tra('Timor-Leste');
tra('Togo');
tra('Tokelau');
tra('Tonga');
tra('Trinidad Tobago');
tra('Tunisia');
tra('Turkey');
tra('Turkmenistan');
tra('Turks and Caicos Islands');
tra('Tuvalu');
tra('Uganda');
tra('Ukraine');
tra('United Arab Emirates');
tra('United Kingdom');
tra('United Nations Organization');
tra('United States');
tra('United States Minor Outlying Islands');
tra('Uruguay');
tra('US Virgin Islands');
tra('Uzbekistan');
tra('Vanuatu');
tra('Vatican');
tra('Venezuela');
tra('Viet Nam');
tra('Wales');
tra('Wallis and Futuna');
tra('Western Sahara');
tra('World');
tra('Yemen');
tra('Yugoslavia');
tra('Zambia');
tra('Zimbabwe');
?>
